==> ntorch_0.2.0.tar.gz: ntorch-0.2.0/mainwindow.cpp <==
#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QtCore/QCoreApplication>

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    ImgOn = ":/images/Light_On.PNG";
    ImgOff = ":/images/Light_Off.png";

    QPixmap pixmap(ImgOn);
    QIcon ButtonIcon(pixmap);
    ui->pushButton->setIcon(ButtonIcon);
    ui->pushButton->setIconSize(pixmap.rect().size());

    bState = false;
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::setOrientation(ScreenOrientation orientation)
{
#if defined(Q_OS_SYMBIAN)
    // If the version of Qt on the device is < 4.7.2, that attribute won't work
    if (orientation != ScreenOrientationAuto) {
        const QStringList v = QString::fromAscii(qVersion()).split(QLatin1Char('.'));
        if (v.count() == 3 && (v.at(0).toInt() << 16 | v.at(1).toInt() << 8 | v.at(2).toInt()) < 0x040702) {
            qWarning("Screen orientation locking only supported with Qt 4.7.2 and above");
            return;
        }
    }
#endif // Q_OS_SYMBIAN

    Qt::WidgetAttribute attribute;
    switch (orientation) {
#if QT_VERSION < 0x040702
    // Qt < 4.7.2 does not yet have the Qt::WA_*Orientation attributes
    case ScreenOrientationLockPortrait:
        attribute = static_cast<Qt::WidgetAttribute>(128);
        break;
    case ScreenOrientationLockLandscape:
        attribute = static_cast<Qt::WidgetAttribute>(129);
        break;
    default:
    case ScreenOrientationAuto:
        attribute = static_cast<Qt::WidgetAttribute>(130);
        break;
#else // QT_VERSION < 0x040702
    case ScreenOrientationLockPortrait:
        attribute = Qt::WA_LockPortraitOrientation;
        break;
    case ScreenOrientationLockLandscape:
        attribute = Qt::WA_LockLandscapeOrientation;
        break;
    default:
    case ScreenOrientationAuto:
        attribute = Qt::WA_AutoOrientation;
        break;
#endif // QT_VERSION < 0x040702
    };
    setAttribute(attribute, true);
}

void MainWindow::showExpanded()
{
#ifdef Q_OS_SYMBIAN
    showFullScreen();
#elif defined(Q_WS_MAEMO_5)
    showMaximized();
#else
    show();
#endif
}

void MainWindow::on_pushButton_clicked()
{
    qDebug() << "on_pushButton_clicked";
    int ret = 0;

    //OFF --> setON
    if(!bState)
    {
        ret = flashlight.setON(0,0);
        if(ret < 1)
            return;

        QPixmap pixmap(ImgOff);
        QIcon ButtonIcon(pixmap);
        ui->pushButton->setIcon(ButtonIcon);
        ui->pushButton->setIconSize(pixmap.rect().size());
        bState = true;

    } else {
        //ON --> setOFF

        ret = flashlight.setOFF();
        if(ret < 1)
            return;

        QPixmap pixmap(ImgOn);
        QIcon ButtonIcon(pixmap);
        ui->pushButton->setIcon(ButtonIcon);
        ui->pushButton->setIconSize(pixmap.rect().size());
        bState = false;
    }
}

void MainWindow::on_actionAbout_triggered()
{
    QMaemo5InformationBox::information(this,
        tr("<br>nTorch<br><br>It switches on/off the dual LED flash of the N900 camera.<br>It is based on the flashlight-applet libraries.<br>Developed by: Raed A.<br>Framework: Qt<br>Email: raedbenz@hotmail.com<br>"),
        QMaemo5InformationBox::NoTimeout);
}

==> ntorch_0.3.0.tar.gz: ntorch-0.3.0/mainwindow.cpp <==
#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QtCore/QCoreApplication>

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    ImgOn = ":/images/Light_On.PNG";
    ImgOff = ":/images/Light_Off.png";

    QPixmap pixmap(ImgOn);
    QIcon ButtonIcon(pixmap);
    ui->pushButton->setIcon(ButtonIcon);
    ui->pushButton->setIconSize(pixmap.rect().size());

    bState = false;
    //qDebug() << getBatteryPercentage();
}


int MainWindow::getBatteryPercentage()
{
    QProcess p;
    p.start("hal-device bme | grep 'percentage'");
    p.waitForFinished(-1);
    QString p_stdout = p.readAllStandardOutput();
    QString p_stderr = p.readAllStandardError();

    //qDebug() << "<"+p_stderr+">";

    if(p_stdout.size() > 0)
    {
	//qDebug() << "<"+p_stdout+">";
	QString p = p_stdout.split(".percentage =")[1];
	p = p.mid(0, p.indexOf("(0x"));
	if(p.size() > 0)
	{
	    p = p.trimmed();
	    bool ok;
	    int i = p.toInt(&ok,10);
	    return i;
	}
    }

    return -1;
}


MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::setOrientation(ScreenOrientation orientation)
{
#if defined(Q_OS_SYMBIAN)
    // If the version of Qt on the device is < 4.7.2, that attribute won't work
    if (orientation != ScreenOrientationAuto) {
        const QStringList v = QString::fromAscii(qVersion()).split(QLatin1Char('.'));
        if (v.count() == 3 && (v.at(0).toInt() << 16 | v.at(1).toInt() << 8 | v.at(2).toInt()) < 0x040702) {
            qWarning("Screen orientation locking only supported with Qt 4.7.2 and above");
            return;
        }
    }
#endif // Q_OS_SYMBIAN

    Qt::WidgetAttribute attribute;
    switch (orientation) {
#if QT_VERSION < 0x040702
    // Qt < 4.7.2 does not yet have the Qt::WA_*Orientation attributes
    case ScreenOrientationLockPortrait:
        attribute = static_cast<Qt::WidgetAttribute>(128);
        break;
    case ScreenOrientationLockLandscape:
        attribute = static_cast<Qt::WidgetAttribute>(129);
        break;
    default:
    case ScreenOrientationAuto:
        attribute = static_cast<Qt::WidgetAttribute>(130);
        break;
#else // QT_VERSION < 0x040702
    case ScreenOrientationLockPortrait:
        attribute = Qt::WA_LockPortraitOrientation;
        break;
    case ScreenOrientationLockLandscape:
        attribute = Qt::WA_LockLandscapeOrientation;
        break;
    default:
    case ScreenOrientationAuto:
        attribute = Qt::WA_AutoOrientation;
        break;
#endif // QT_VERSION < 0x040702
    };
    setAttribute(attribute, true);
}

void MainWindow::showExpanded()
{
#ifdef Q_OS_SYMBIAN
    showFullScreen();
#elif defined(Q_WS_MAEMO_5)
    showMaximized();
#else
    show();
#endif
}

void MainWindow::on_pushButton_clicked()
{
    qDebug() << "on_pushButton_clicked";
    int ret = 0;

    //OFF --> setON
    if(!bState)
    {
        ret = flashlight.setON(0,0);
        if(ret < 1)
            return;

        QPixmap pixmap(ImgOff);
        QIcon ButtonIcon(pixmap);
        ui->pushButton->setIcon(ButtonIcon);
        ui->pushButton->setIconSize(pixmap.rect().size());
        bState = true;

    } else {
        //ON --> setOFF

        ret = flashlight.setOFF();
        if(ret < 1)
            return;

        QPixmap pixmap(ImgOn);
        QIcon ButtonIcon(pixmap);
        ui->pushButton->setIcon(ButtonIcon);
        ui->pushButton->setIconSize(pixmap.rect().size());
        bState = false;
    }
}

void MainWindow::on_actionAbout_triggered()
{
    QMaemo5InformationBox::information(this,
        tr("<br>nTorch<br><br>It switches on/off the dual LED flash of the N900 camera.<br>It is based on the flashlight-applet libraries.<br>Developed by: Raed A.<br>Framework: Qt<br>Email: raedbenz@hotmail.com<br>"),
        QMaemo5InformationBox::NoTimeout);
}
